@@ -862,9 +862,7 @@ class App(Generic[ReturnType], DOMNode):
         assert driver is not None
         await wait_for_idle(0)
         for key in keys:
-            if key == "_":
-                continue
-            elif key.startswith("wait:"):
+            if key.startswith("wait:"):
                 _, wait_ms = key.split(":")
                 print(f"(pause {wait_ms}ms)")
                 await asyncio.sleep(float(wait_ms) / 1000)
@@ -1827,13 +1825,14 @@ class App(Generic[ReturnType], DOMNode):
 
         await self._dispatch_message(events.Unmount())
 
-        self._print_error_renderables()
         if self.devtools is not None and self.devtools.is_connected:
             await self._disconnect_devtools()
 
         if self._writer_thread is not None:
             self._writer_thread.stop()
 
+        self._print_error_renderables()
+
     async def _on_exit_app(self) -> None:
         self._begin_batch()  # Prevent repaint / layout while shutting down
         await self._message_queue.put(None)
@@ -1936,7 +1935,7 @@ class App(Generic[ReturnType], DOMNode):
         ):
             binding = bindings.keys.get(key)
             if binding is not None and binding.priority == priority:
-                if await self.action(binding.action, namespace):
+                if await self.run_action(binding.action, namespace):
                     return True
         return False
 
@@ -1969,7 +1968,7 @@ class App(Generic[ReturnType], DOMNode):
         else:
             await super().on_event(event)
 
-    async def action(
+    async def run_action(
         self,
         action: str | ActionParseResult,
         default_namespace: object | None = None,
@@ -2068,7 +2067,7 @@ class App(Generic[ReturnType], DOMNode):
         else:
             event.stop()
         if isinstance(action, (str, tuple)):
-            await self.action(action, default_namespace=default_namespace)  # type: ignore[arg-type]
+            await self.run_action(action, default_namespace=default_namespace)  # type: ignore[arg-type]
         elif callable(action):
             await action()
         else:
@@ -2175,7 +2174,7 @@ class App(Generic[ReturnType], DOMNode):
             for child in widget._nodes:
                 push(child)
 
-    def _remove_nodes(self, widgets: list[Widget]) -> AwaitRemove:
+    def _remove_nodes(self, widgets: list[Widget], parent: DOMNode) -> AwaitRemove:
         """Remove nodes from DOM, and return an awaitable that awaits cleanup.
 
         Args:
@@ -2198,7 +2197,8 @@ class App(Generic[ReturnType], DOMNode):
                 await self._prune_nodes(widgets)
             finally:
                 finished_event.set()
-                self.refresh(layout=True)
+                if parent.styles.auto_dimensions:
+                    parent.refresh(layout=True)
 
         removed_widgets = self._detach_from_dom(widgets)
 
