@@ -21,6 +21,7 @@ if typing.TYPE_CHECKING:
     from ._label import Label
     from ._list_item import ListItem
     from ._list_view import ListView
+    from ._loading_indicator import LoadingIndicator
     from ._markdown import Markdown, MarkdownViewer
     from ._placeholder import Placeholder
     from ._pretty import Pretty
@@ -28,6 +29,7 @@ if typing.TYPE_CHECKING:
     from ._radio_set import RadioSet
     from ._static import Static
     from ._switch import Switch
+    from ._tabs import Tab, Tabs
     from ._text_log import TextLog
     from ._tree import Tree
     from ._welcome import Welcome
@@ -45,6 +47,7 @@ __all__ = [
     "Label",
     "ListItem",
     "ListView",
+    "LoadingIndicator",
     "Markdown",
     "MarkdownViewer",
     "Placeholder",
@@ -53,6 +56,8 @@ __all__ = [
     "RadioSet",
     "Static",
     "Switch",
+    "Tab",
+    "Tabs",
     "TextLog",
     "Tree",
     "Welcome",
