@@ -21,6 +21,7 @@ from .._segment_tools import line_crop
 from .._two_way_dict import TwoWayDict
 from .._types import SegmentLines
 from ..binding import Binding, BindingType
+from ..color import Color
 from ..coordinate import Coordinate
 from ..geometry import Region, Size, Spacing, clamp
 from ..message import Message
@@ -319,25 +320,31 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
 
         def __init__(
             self,
-            sender: DataTable,
+            data_table: DataTable,
             value: CellType,
             coordinate: Coordinate,
             cell_key: CellKey,
         ) -> None:
+            self.data_table = data_table
+            """The data table."""
             self.value: CellType = value
             """The value in the highlighted cell."""
             self.coordinate: Coordinate = coordinate
             """The coordinate of the highlighted cell."""
             self.cell_key: CellKey = cell_key
             """The key for the highlighted cell."""
-            super().__init__(sender)
+            super().__init__()
 
         def __rich_repr__(self) -> rich.repr.Result:
-            yield "sender", self.sender
             yield "value", self.value
             yield "coordinate", self.coordinate
             yield "cell_key", self.cell_key
 
+        @property
+        def control(self) -> DataTable:
+            """Alias for the data table."""
+            return self.data_table
+
     class CellSelected(Message, bubble=True):
         """Posted by the `DataTable` widget when a cell is selected.
 
@@ -348,25 +355,31 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
 
         def __init__(
             self,
-            sender: DataTable,
+            data_table: DataTable,
             value: CellType,
             coordinate: Coordinate,
             cell_key: CellKey,
         ) -> None:
+            self.data_table = data_table
+            """The data table."""
             self.value: CellType = value
             """The value in the cell that was selected."""
             self.coordinate: Coordinate = coordinate
             """The coordinate of the cell that was selected."""
             self.cell_key: CellKey = cell_key
             """The key for the selected cell."""
-            super().__init__(sender)
+            super().__init__()
 
         def __rich_repr__(self) -> rich.repr.Result:
-            yield "sender", self.sender
             yield "value", self.value
             yield "coordinate", self.coordinate
             yield "cell_key", self.cell_key
 
+        @property
+        def control(self) -> DataTable:
+            """Alias for the data table."""
+            return self.data_table
+
     class RowHighlighted(Message, bubble=True):
         """Posted when a row is highlighted.
 
@@ -376,18 +389,26 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         widget in the DOM.
         """
 
-        def __init__(self, sender: DataTable, cursor_row: int, row_key: RowKey) -> None:
+        def __init__(
+            self, data_table: DataTable, cursor_row: int, row_key: RowKey
+        ) -> None:
+            self.data_table = data_table
+            """The data table."""
             self.cursor_row: int = cursor_row
             """The y-coordinate of the cursor that highlighted the row."""
             self.row_key: RowKey = row_key
             """The key of the row that was highlighted."""
-            super().__init__(sender)
+            super().__init__()
 
         def __rich_repr__(self) -> rich.repr.Result:
-            yield "sender", self.sender
             yield "cursor_row", self.cursor_row
             yield "row_key", self.row_key
 
+        @property
+        def control(self) -> DataTable:
+            """Alias for the data table."""
+            return self.data_table
+
     class RowSelected(Message, bubble=True):
         """Posted when a row is selected.
 
@@ -397,18 +418,26 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         widget in the DOM.
         """
 
-        def __init__(self, sender: DataTable, cursor_row: int, row_key: RowKey) -> None:
+        def __init__(
+            self, data_table: DataTable, cursor_row: int, row_key: RowKey
+        ) -> None:
+            self.data_table = data_table
+            """The data table."""
             self.cursor_row: int = cursor_row
             """The y-coordinate of the cursor that made the selection."""
             self.row_key: RowKey = row_key
             """The key of the row that was selected."""
-            super().__init__(sender)
+            super().__init__()
 
         def __rich_repr__(self) -> rich.repr.Result:
-            yield "sender", self.sender
             yield "cursor_row", self.cursor_row
             yield "row_key", self.row_key
 
+        @property
+        def control(self) -> DataTable:
+            """Alias for the data table."""
+            return self.data_table
+
     class ColumnHighlighted(Message, bubble=True):
         """Posted when a column is highlighted.
 
@@ -419,19 +448,25 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         """
 
         def __init__(
-            self, sender: DataTable, cursor_column: int, column_key: ColumnKey
+            self, data_table: DataTable, cursor_column: int, column_key: ColumnKey
         ) -> None:
+            self.data_table = data_table
+            """The data table."""
             self.cursor_column: int = cursor_column
             """The x-coordinate of the column that was highlighted."""
             self.column_key = column_key
             """The key of the column that was highlighted."""
-            super().__init__(sender)
+            super().__init__()
 
         def __rich_repr__(self) -> rich.repr.Result:
-            yield "sender", self.sender
             yield "cursor_column", self.cursor_column
             yield "column_key", self.column_key
 
+        @property
+        def control(self) -> DataTable:
+            """Alias for the data table."""
+            return self.data_table
+
     class ColumnSelected(Message, bubble=True):
         """Posted when a column is selected.
 
@@ -442,67 +477,85 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         """
 
         def __init__(
-            self, sender: DataTable, cursor_column: int, column_key: ColumnKey
+            self, data_table: DataTable, cursor_column: int, column_key: ColumnKey
         ) -> None:
+            self.data_table = data_table
+            """The data table."""
             self.cursor_column: int = cursor_column
             """The x-coordinate of the column that was selected."""
             self.column_key = column_key
             """The key of the column that was selected."""
-            super().__init__(sender)
+            super().__init__()
 
         def __rich_repr__(self) -> rich.repr.Result:
-            yield "sender", self.sender
             yield "cursor_column", self.cursor_column
             yield "column_key", self.column_key
 
+        @property
+        def control(self) -> DataTable:
+            """Alias for the data table."""
+            return self.data_table
+
     class HeaderSelected(Message, bubble=True):
         """Posted when a column header/label is clicked."""
 
         def __init__(
             self,
-            sender: DataTable,
+            data_table: DataTable,
             column_key: ColumnKey,
             column_index: int,
             label: Text,
         ):
+            self.data_table = data_table
+            """The data table."""
             self.column_key = column_key
             """The key for the column."""
             self.column_index = column_index
             """The index for the column."""
             self.label = label
             """The text of the label."""
-            super().__init__(sender)
+            super().__init__()
 
         def __rich_repr__(self) -> rich.repr.Result:
-            yield "sender", self.sender
             yield "column_key", self.column_key
             yield "column_index", self.column_index
             yield "label", self.label.plain
 
+        @property
+        def control(self) -> DataTable:
+            """Alias for the data table."""
+            return self.data_table
+
     class RowLabelSelected(Message, bubble=True):
         """Posted when a row label is clicked."""
 
         def __init__(
             self,
-            sender: DataTable,
+            data_table: DataTable,
             row_key: RowKey,
             row_index: int,
             label: Text,
         ):
+            self.data_table = data_table
+            """The data table."""
             self.row_key = row_key
             """The key for the column."""
             self.row_index = row_index
             """The index for the column."""
             self.label = label
             """The text of the label."""
-            super().__init__(sender)
+            super().__init__()
 
         def __rich_repr__(self) -> rich.repr.Result:
-            yield "sender", self.sender
             yield "row_key", self.row_key
             yield "row_index", self.row_index
             yield "label", self.label.plain
 
+        @property
+        def control(self) -> DataTable:
+            """Alias for the data table."""
+            return self.data_table
+
     def __init__(
         self,
         *,
@@ -828,6 +881,9 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         self._clear_caches()
         self.refresh()
 
+    def on_resize(self, event: events.Resize) -> None:
+        self._update_count += 1
+
     def watch_show_cursor(self, show_cursor: bool) -> None:
         self._clear_caches()
         if show_cursor and self.cursor_type != "none":
@@ -896,7 +952,7 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
             return
         else:
             cell_key = self.coordinate_to_cell_key(coordinate)
-            self.post_message_no_wait(
+            self.post_message(
                 DataTable.CellHighlighted(
                     self, cell_value, coordinate=coordinate, cell_key=cell_key
                 )
@@ -927,16 +983,14 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         is_valid_row = row_index < len(self._data)
         if is_valid_row:
             row_key = self._row_locations.get_key(row_index)
-            self.post_message_no_wait(
-                DataTable.RowHighlighted(self, row_index, row_key)
-            )
+            self.post_message(DataTable.RowHighlighted(self, row_index, row_key))
 
     def _highlight_column(self, column_index: int) -> None:
         """Apply highlighting to the column at the given index, and post event."""
         self.refresh_column(column_index)
         if column_index < len(self.columns):
             column_key = self._column_locations.get_key(column_index)
-            self.post_message_no_wait(
+            self.post_message(
                 DataTable.ColumnHighlighted(self, column_index, column_key)
             )
 
@@ -1015,6 +1069,12 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         console = self.app.console
         for row_key in new_rows:
             row_index = self._row_locations.get(row_key)
+
+            # The row could have been removed before on_idle was called, so we
+            # need to be quite defensive here and don't assume that the row exists.
+            if row_index is None:
+                continue
+
             row = self.rows.get(row_key)
 
             if row.label is not None:
@@ -1026,9 +1086,6 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
                 self._label_column.content_width, label_content_width
             )
 
-            if row_index is None:
-                continue
-
             for column, renderable in zip(self.ordered_columns, cells_in_row):
                 content_width = measure(console, renderable, 1)
                 column.content_width = max(column.content_width, content_width)
@@ -1632,6 +1689,25 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
             )[line_no]
             scrollable_row.append(cell_lines)
 
+        # Extending the styling out horizontally to fill the container
+        widget_width = self.size.width
+        table_width = (
+            sum(
+                column.render_width
+                for column in self.ordered_columns[self.fixed_columns :]
+            )
+            + self._row_label_column_width
+        )
+        remaining_space = max(0, widget_width - table_width)
+        background_color = self.background_colors[1]
+        faded_color = Color.from_rich_color(row_style.bgcolor).blend(
+            background_color, factor=0.25
+        )
+        faded_style = Style.from_color(
+            color=row_style.color, bgcolor=faded_color.rich_color
+        )
+        scrollable_row.append([Segment(" " * remaining_space, faded_style)])
+
         row_pair = (fixed_row, scrollable_row)
         self._row_render_cache[cache_key] = row_pair
         return row_pair
@@ -1737,6 +1813,7 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         and column metadata from the segments present in the cells."""
         self._set_hover_cursor(True)
         meta = event.style.meta
+
         if meta and self.show_cursor and self.cursor_type != "none":
             try:
                 self.hover_coordinate = Coordinate(meta["row"], meta["column"])
@@ -1823,7 +1900,7 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
 
     def on_click(self, event: events.Click) -> None:
         self._set_hover_cursor(True)
-        meta = self.get_style_at(event.x, event.y).meta
+        meta = event.style.meta
         if not meta:
             return
 
@@ -1837,13 +1914,13 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
             message = DataTable.HeaderSelected(
                 self, column.key, column_index, label=column.label
             )
-            self.post_message_no_wait(message)
+            self.post_message(message)
         elif is_row_label_click:
             row = self.ordered_rows[row_index]
             message = DataTable.RowLabelSelected(
                 self, row.key, row_index, label=row.label
             )
-            self.post_message_no_wait(message)
+            self.post_message(message)
         elif self.show_cursor and self.cursor_type != "none":
             # Only post selection events if there is a visible row/col/cell cursor.
             self.cursor_coordinate = Coordinate(row_index, column_index)
@@ -1898,9 +1975,11 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         """Post the appropriate message for a selection based on the `cursor_type`."""
         cursor_coordinate = self.cursor_coordinate
         cursor_type = self.cursor_type
+        if len(self._data) == 0:
+            return
         cell_key = self.coordinate_to_cell_key(cursor_coordinate)
         if cursor_type == "cell":
-            self.post_message_no_wait(
+            self.post_message(
                 DataTable.CellSelected(
                     self,
                     self.get_cell_at(cursor_coordinate),
@@ -1911,10 +1990,8 @@ class DataTable(ScrollView, Generic[CellType], can_focus=True):
         elif cursor_type == "row":
             row_index, _ = cursor_coordinate
             row_key, _ = cell_key
-            self.post_message_no_wait(DataTable.RowSelected(self, row_index, row_key))
+            self.post_message(DataTable.RowSelected(self, row_index, row_key))
         elif cursor_type == "column":
             _, column_index = cursor_coordinate
             _, column_key = cell_key
-            self.post_message_no_wait(
-                DataTable.ColumnSelected(self, column_index, column_key)
-            )
+            self.post_message(DataTable.ColumnSelected(self, column_index, column_key))
