@@ -1,16 +1,14 @@
 from __future__ import annotations
 
 import pytest
-from rich.style import Style
 from rich.text import Text
 
 from textual._wait import wait_for_idle
 from textual.actions import SkipAction
 from textual.app import App
 from textual.coordinate import Coordinate
-from textual.events import Click, MouseMove
+from textual.geometry import Offset
 from textual.message import Message
-from textual.message_pump import MessagePump
 from textual.widgets import DataTable
 from textual.widgets.data_table import (
     CellDoesNotExist,
@@ -166,6 +164,13 @@ async def test_datatable_message_emission():
         assert app.message_names == expected_messages
 
 
+async def test_empty_table_interactions():
+    app = DataTableApp()
+    async with app.run_test() as pilot:
+        await pilot.press("enter", "up", "down", "left", "right")
+        assert app.message_names == []
+
+
 async def test_add_rows():
     app = DataTableApp()
     async with app.run_test():
@@ -556,33 +561,17 @@ async def test_coordinate_to_cell_key_invalid_coordinate():
             table.coordinate_to_cell_key(Coordinate(9999, 9999))
 
 
-def make_click_event(sender: MessagePump):
-    return Click(
-        sender=sender,
-        x=1,
-        y=2,
-        delta_x=0,
-        delta_y=0,
-        button=0,
-        shift=False,
-        meta=False,
-        ctrl=False,
-    )
-
-
-async def test_datatable_on_click_cell_cursor():
+async def test_datatable_click_cell_cursor():
     """When the cell cursor is used, and we click, we emit a CellHighlighted
     *and* a CellSelected message for the cell that was clicked.
     Regression test for https://github.com/Textualize/textual/issues/1723"""
     app = DataTableApp()
     async with app.run_test() as pilot:
         table = app.query_one(DataTable)
-        click = make_click_event(app)
         column_key = table.add_column("ABC")
         table.add_row("123")
         row_key = table.add_row("456")
-        table.on_click(event=click)
-        await pilot.pause()
+        await pilot.click(offset=Offset(1, 2))
         # There's two CellHighlighted events since a cell is highlighted on initial load,
         # then when we click, another cell is highlighted (and selected).
         assert app.message_names == [
@@ -591,69 +580,60 @@ async def test_datatable_on_click_cell_cursor():
             "CellSelected",
         ]
         cell_highlighted_event: DataTable.CellHighlighted = app.messages[1]
-        assert cell_highlighted_event.sender is table
         assert cell_highlighted_event.value == "456"
         assert cell_highlighted_event.cell_key == CellKey(row_key, column_key)
         assert cell_highlighted_event.coordinate == Coordinate(1, 0)
 
         cell_selected_event: DataTable.CellSelected = app.messages[2]
-        assert cell_selected_event.sender is table
         assert cell_selected_event.value == "456"
         assert cell_selected_event.cell_key == CellKey(row_key, column_key)
         assert cell_selected_event.coordinate == Coordinate(1, 0)
 
 
-async def test_on_click_row_cursor():
+async def test_click_row_cursor():
     """When the row cursor is used, and we click, we emit a RowHighlighted
     *and* a RowSelected message for the row that was clicked."""
     app = DataTableApp()
-    async with app.run_test():
+    async with app.run_test() as pilot:
         table = app.query_one(DataTable)
         table.cursor_type = "row"
-        click = make_click_event(app)
         table.add_column("ABC")
         table.add_row("123")
         row_key = table.add_row("456")
-        table.on_click(event=click)
-        await wait_for_idle(0)
+        await pilot.click(offset=Offset(1, 2))
         assert app.message_names == ["RowHighlighted", "RowHighlighted", "RowSelected"]
 
         row_highlighted: DataTable.RowHighlighted = app.messages[1]
-        assert row_highlighted.sender is table
+
         assert row_highlighted.row_key == row_key
         assert row_highlighted.cursor_row == 1
 
         row_selected: DataTable.RowSelected = app.messages[2]
-        assert row_selected.sender is table
         assert row_selected.row_key == row_key
         assert row_highlighted.cursor_row == 1
 
 
-async def test_on_click_column_cursor():
+async def test_click_column_cursor():
     """When the column cursor is used, and we click, we emit a ColumnHighlighted
     *and* a ColumnSelected message for the column that was clicked."""
     app = DataTableApp()
-    async with app.run_test():
+    async with app.run_test() as pilot:
         table = app.query_one(DataTable)
         table.cursor_type = "column"
         column_key = table.add_column("ABC")
         table.add_row("123")
         table.add_row("456")
-        click = make_click_event(app)
-        table.on_click(event=click)
-        await wait_for_idle(0)
+        await pilot.click(offset=Offset(1, 2))
         assert app.message_names == [
             "ColumnHighlighted",
             "ColumnHighlighted",
             "ColumnSelected",
         ]
         column_highlighted: DataTable.ColumnHighlighted = app.messages[1]
-        assert column_highlighted.sender is table
         assert column_highlighted.column_key == column_key
         assert column_highlighted.cursor_column == 0
 
         column_selected: DataTable.ColumnSelected = app.messages[2]
-        assert column_selected.sender is table
         assert column_selected.column_key == column_key
         assert column_highlighted.cursor_column == 0
 
@@ -661,28 +641,14 @@ async def test_on_click_column_cursor():
 async def test_hover_coordinate():
     """Ensure that the hover_coordinate reactive is updated as expected."""
     app = DataTableApp()
-    async with app.run_test():
+    async with app.run_test() as pilot:
         table = app.query_one(DataTable)
         table.add_column("ABC")
         table.add_row("123")
         table.add_row("456")
         assert table.hover_coordinate == Coordinate(0, 0)
-
-        mouse_move = MouseMove(
-            sender=app,
-            x=1,
-            y=2,
-            delta_x=0,
-            delta_y=0,
-            button=0,
-            shift=False,
-            meta=False,
-            ctrl=False,
-            style=Style(meta={"row": 1, "column": 2}),
-        )
-        table.on_mouse_move(mouse_move)
-        await wait_for_idle(0)
-        assert table.hover_coordinate == Coordinate(1, 2)
+        await pilot.hover(DataTable, offset=Offset(2, 2))
+        assert table.hover_coordinate == Coordinate(1, 0)
 
 
 async def test_header_selected():
@@ -693,29 +659,17 @@ async def test_header_selected():
         table = app.query_one(DataTable)
         column_key = table.add_column("number")
         table.add_row(3)
-        click_event = Click(
-            sender=table,
-            x=3,
-            y=0,
-            delta_x=0,
-            delta_y=0,
-            button=1,
-            shift=False,
-            meta=False,
-            ctrl=False,
-        )
-        await pilot.pause()
-        table.on_click(click_event)
-        await pilot.pause()
+
+        click_location = Offset(3, 0)  # Click the header
+        await pilot.click(DataTable, offset=click_location)
         message: DataTable.HeaderSelected = app.messages[-1]
-        assert message.sender is table
         assert message.label == Text("number")
         assert message.column_index == 0
         assert message.column_key == column_key
 
         # Now hide the header and click in the exact same place - no additional message emitted.
         table.show_header = False
-        table.on_click(click_event)
+        await pilot.click(DataTable, offset=click_location)
         await pilot.pause()
         assert app.message_names.count("HeaderSelected") == 1
 
@@ -728,30 +682,16 @@ async def test_row_label_selected():
         table = app.query_one(DataTable)
         table.add_column("number")
         row_key = table.add_row(3, label="A")
-        click_event = Click(
-            sender=table,
-            x=1,
-            y=1,
-            delta_x=0,
-            delta_y=0,
-            button=1,
-            shift=False,
-            meta=False,
-            ctrl=False,
-        )
-        await pilot.pause()
-        table.on_click(click_event)
         await pilot.pause()
+        await pilot.click(DataTable, offset=Offset(1, 1))
         message: DataTable.RowLabelSelected = app.messages[-1]
-        assert message.sender is table
         assert message.label == Text("A")
         assert message.row_index == 0
         assert message.row_key == row_key
 
         # Now hide the row label and click in the same place - no additional message emitted.
         table.show_row_labels = False
-        table.on_click(click_event)
-        await pilot.pause()
+        await pilot.click(DataTable, offset=Offset(1, 1))
         assert app.message_names.count("RowLabelSelected") == 1
 
 
